#version 460

// uniforms
uniform vec4 l_dir; // world space
uniform mat4 m_pvm;
uniform mat3 m_normal;
uniform mat4 m_view;

uniform vec4 diffuse;
uniform float threshold1 = 0.25;
uniform float threshold2 = 0.50;
uniform float threshold3 = 0.75;
uniform float threshold4 = 0.90;

// input streams
in vec4 position; // local space
in vec3 normal;   // local space

// output
out vec4 c;

void main() {

    // convert normal to camera space and normalize
    vec3 n = normalize(m_normal * normal);

    // convert l_dir to camera space and normalize
    vec3 l = normalize(vec3(m_view * -l_dir));

    // compute intensity
    float i = max(0.0, dot(n,l));

    float intensity;
    if (i < threshold1)
        intensity = threshold1;
    else if (i < threshold2)
        intensity = threshold2;
    else if (i < threshold3)
        intensity = threshold3;
    else
        intensity = threshold4;

    c = diffuse * intensity;

    gl_Position = m_pvm * position;

}